==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/userconf/userconf.m <==
extern const char **_dictionary_userconf;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_userconf;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_userconf("userconf",_dictionary_userconf,258,15);\
	void dummy_dict_userconf(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_userconf[id]
	#define MSG_B(id,m,n)	_dictionary_userconf[id]
	#define MSG_R(id)	_dictionary_userconf[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_userconf,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_userconf,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_userconf,id)
#endif
#define E_GROUPEXIST	0
#define E_GROUPEXISTID	1
#define E_UNKNOWNMEMBER	2
#define F_GROUPNAME	3
#define F_GROUPID	4
#define F_ALTMEM	5
#define T_GROUPSPEC	6
#define INTRO_GROUPSPEC	7
#define P_GROUPDB	8
#define T_GROUPS	9
#define I_GROUPS	10
#define I_TOADD	11
#define I_GROUPCREATE	12
#define Q_GROUPCREATE	13
#define P_PASSPOLICIES	14
#define F_MINLEN	15
#define F_MINCHARS	16
#define T_PASSPOLICIES	17
#define I_PASSPOLICIES	18
#define E_NOROOT	19
#define T_PASSREQ	20
#define I_ENTERPASS	21
#define E_IVLDPASS	22
#define E_MUSTBEROOT	23
#define E_DUPLOGIN	24
#define E_DUPID	25
#define E_UNKNOWNGRP	26
#define E_IVLDSHELL	27
#define E_NOSHELL	28
#define E_NOHOME	29
#define N_IS_OK	30
#define E_IVLDGRP	31
#define E_IVLDOWN	32
#define E_IVLDG_O	33
#define E_EXISTDIR	34
#define E_DONOTEXIST	35
#define E_HOMEUSER	36
#define P_SETUSERDIR	37
#define E_SETUPDIR	38
#define F_LOGIN	39
#define F_FULLNAME	40
#define F_GROUP	41
#define F_HOME	42
#define F_SHELL	43
#define F_UID	44
#define T_USERINFO	45
#define I_USERINTRO	46
#define P_USERDATA	47
#define E_NO2PT	48
#define Q_CREATE	49
#define Q_FIXIT	50
#define Q_USERHOME	51
#define E_NULLPASS	52
#define E_WEAKPASS	53
#define F_PASSWORD	54
#define F_CONFIRM	55
#define T_PASSWORD	56
#define I_PASSINTRO	57
#define E_MISMATCH	58
#define N_ACCEPT	59
#define T_CHGYOURPASS	60
#define I_ENTERYOURPASS	61
#define M_USER	62
#define M_GROUPDEF	63
#define M_ROOTPASS	64
#define M_PPP	65
#define M_SLIP	66
#define M_UUCP	67
#define M_POP	68
#define M_POLICIES	69
#define T_UCONF	70
#define I_UCONFINTRO	71
#define P_POP	72
#define P_PPP	73
#define P_SLIP	74
#define P_UUCP	75
#define P_CHGPASS	76
#define E_NOUID	77
#define E_UNKNOWNUSER	78
#define T_USERACCT	79
#define I_CANEDIT	80
#define I_SELECT	81
#define P_USERDB	82
#define I_USERCREATE	83
#define Q_USERCREATE	84
#define W_CHGPASS	85
#define Q_ENTEROLDPASS	86
#define Q_ENTERNEWPASS	87
#define Q_RETYPE	88
#define Q_DELGROUP	89
#define T_PASSMNG	90
#define F_PASSMAY	91
#define F_PASSMUST	92
#define F_PASSWARN	93
#define F_PASSEXPIRE	94
#define B_PASSWD	95
#define T_PRIVILEGES	96
#define E_NOUSER	97
#define F_ROOTPASS	98
#define F_YOURPASS	99
#define F_MANAGEPOP	100
#define F_MANAGEPPP	101
#define F_MANAGEUUCP	102
#define I_ENTERONEPASS	103
#define E_NOUSERFROMID	104
#define I_EMPTYLINE	105
#define E_SHELLUNKNOWN	106
#define T_USERSHELL	107
#define T_PPPSHELL	108
#define T_SLIPSHELL	109
#define M_USRSHELLS	110
#define M_PPPSHELLS	111
#define M_SLPSHELLS	112
#define T_MANAGEACCT	113
#define O_DENY	114
#define O_PRIVENABLE	115
#define O_PRIVNOAUTH	116
#define F_PRIVENABLE	117
#define E_ROOTID	118
#define T_NEWUSER	119
#define F_WASCHG	120
#define F_STDDURATION	121
#define F_WASISDIS	122
#define E_IVLDDATE	123
#define E_ROOTPASS	124
#define M_EALIAS	125
#define E_SHELLNOTEXEC	126
#define F_NEWPASSWORD	127
#define F_PASSCONFIRM	128
#define T_IDENTIFY	129
#define I_IDENTIFY	130
#define E_IVLDUPASS	131
#define F_ACCOUNT	132
#define F_CURPASSWORD	133
#define N_NEWPASSOK	134
#define I_SERVER	135
#define E_UPASSROOT	136
#define E_ACCTLOCKED	137
#define E_PASSLOCKED	138
#define E_PASSWAIT	139
#define E_PICKNEW	140
#define F_CRONRANGE	141
#define F_COMMAND	142
#define F_MONTHS	143
#define F_ISJANUARY	144
#define F_ISDECEMBER	145
#define F_DMONTH	146
#define F_DWEEK	147
#define F_ISSUNDAY	148
#define F_ISSATURDAY	149
#define F_HOURS	150
#define F_MINUTES	151
#define T_CRONENTRY	152
#define I_CRONENTRY	153
#define T_JOBS	154
#define B_TASKS	155
#define F_3VALUES	156
#define F_CRONSTEP	157
#define F_ENABLED	158
#define P_CRON	159
#define F_EVERY	160
#define F_MONTH	161
#define F_DAYOFMONTH	162
#define F_DAYOFWEEK	163
#define F_hOURS	164
#define F_mINUTES	165
#define T_BASE	166
#define T_PARAMS	167
#define M_NORMAL	168
#define T_PRIVROOTEQUIV	169
#define T_PSYSCONTROL	170
#define T_CHGROOTPASS	171
#define I_ENTERROOTPASS	172
#define T_POLICIES	173
#define E_PASSWDCMD	174
#define E_UNLOCKPASS	175
#define H_GROUPS	176
#define F_USERPREFIX	177
#define I_USERPREFIX	178
#define T_USERPREFIX	179
#define H_USERS	180
#define T_GDISKQUOTA	181
#define T_UDEFDISKQUOTA	182
#define T_DISKQUOTA	183
#define F_DEFSHELL	184
#define E_IVLDDEF	185
#define E_NOSPACE	186
#define E_IVLDPERIOD	187
#define E_UEXIST	188
#define E_UNOTEXIST	189
#define T_SPCACCTS	190
#define X_PASSWD	191
#define X_TASKS	192
#define F_DEFHOME	193
#define E_GNOTEXIST	194
#define F_NEWUSERCMD	195
#define F_DELETECMD	196
#define E_NOTDEL	197
#define I_NOTDEL	198
#define E_DELANYWAY	199
#define I_DELANYWAY	200
#define E_PREDELFAIL	201
#define F_PRIVGROUP	202
#define I_PRIVGROUP	203
#define E_NOGROUP	204
#define I_CREATEGROUP	205
#define T_CREATGROUP	206
#define F_SUPGROUP	207
#define E_IVLDSUPGROUP	208
#define F_GECOSPREFIX	209
#define F_UID_FROM	210
#define F_UID_TO	211
#define E_GEXIST	212
#define F_GROUPOPT	213
#define F_ARCHIVECMD	214
#define F_POSTDELCMD	215
#define I_ARCHACCTDATA	216
#define I_DELACCTDATA	217
#define I_LEAVEDATA	218
#define T_DELACCT	219
#define I_DELACCT	220
#define I_ENABLED	221
#define T_YOURNAME	222
#define I_YOURNAME	223
#define E_PASSCHG	224
#define I_DELETING	225
#define I_CREATING	226
#define T_SPCLINKS	227
#define T_CHGPASS	228
#define T_EdITUSERS	229
#define T_HOMEDIRS	230
#define F_DIFFDIR	231
#define I_CREATEHOME	232
#define F_HOMEBASE	233
#define F_CREATEPERM	234
#define Q_MISSBASE	235
#define T_MISSBASE	236
#define E_IVLDDIR	237
#define I_USAGE	238
#define F_DONOTHING	239
#define F_CHOWNDIR	240
#define T_FIXHOME	241
#define F_CHOWNRECUR	242
#define I_IGNORED	243
#define T_USERPRIVI	244
#define T_GENPRIVI	245
#define T_USERADMPRIVI	246
#define T_THISHELP	247
#define E_IVLDLOGINCHAR	248
#define E_FAILCREATE	249
#define P_USERACCOUTS	250
#define N_MAXALTGR	251
#define I_SHOWSHADOW	252
#define I_EDITHOME	253
#define T_SCRIPTS	254
#define I_EDITSHELL	255
#define I_EDITQUOTA	256
#define I_EDITTASKS	257

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/userconf/userconf.m <==
extern const char **_dictionary_userconf;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_userconf;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_userconf("userconf",_dictionary_userconf,269,15);\
	void dummy_dict_userconf(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_userconf[id]
	#define MSG_B(id,m,n)	_dictionary_userconf[id]
	#define MSG_R(id)	_dictionary_userconf[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_userconf,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_userconf,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_userconf,id)
#endif
#define E_GROUPEXIST	0
#define E_GROUPEXISTID	1
#define E_UNKNOWNMEMBER	2
#define F_GROUPNAME	3
#define F_GROUPID	4
#define F_ALTMEM	5
#define T_GROUPSPEC	6
#define INTRO_GROUPSPEC	7
#define P_GROUPDB	8
#define T_GROUPS	9
#define I_GROUPS	10
#define I_TOADD	11
#define I_GROUPCREATE	12
#define Q_GROUPCREATE	13
#define P_PASSPOLICIES	14
#define F_MINLEN	15
#define F_MINCHARS	16
#define T_PASSPOLICIES	17
#define I_PASSPOLICIES	18
#define E_NOROOT	19
#define T_PASSREQ	20
#define I_ENTERPASS	21
#define E_IVLDPASS	22
#define E_MUSTBEROOT	23
#define E_DUPLOGIN	24
#define E_DUPID	25
#define E_UNKNOWNGRP	26
#define E_IVLDSHELL	27
#define E_NOSHELL	28
#define E_NOHOME	29
#define N_IS_OK	30
#define E_IVLDGRP	31
#define E_IVLDOWN	32
#define E_IVLDG_O	33
#define E_EXISTDIR	34
#define E_DONOTEXIST	35
#define E_HOMEUSER	36
#define P_SETUSERDIR	37
#define E_SETUPDIR	38
#define F_LOGIN	39
#define F_FULLNAME	40
#define F_GROUP	41
#define F_HOME	42
#define F_SHELL	43
#define F_UID	44
#define T_USERINFO	45
#define I_USERINTRO	46
#define P_USERDATA	47
#define E_NO2PT	48
#define Q_CREATE	49
#define Q_FIXIT	50
#define Q_USERHOME	51
#define E_NULLPASS	52
#define E_WEAKPASS	53
#define F_PASSWORD	54
#define F_CONFIRM	55
#define T_PASSWORD	56
#define I_PASSINTRO	57
#define E_MISMATCH	58
#define N_ACCEPT	59
#define T_CHGYOURPASS	60
#define I_ENTERYOURPASS	61
#define M_USER	62
#define M_GROUPDEF	63
#define M_ROOTPASS	64
#define M_PPP	65
#define M_SLIP	66
#define M_UUCP	67
#define M_POP	68
#define M_POLICIES	69
#define T_UCONF	70
#define I_UCONFINTRO	71
#define P_POP	72
#define P_PPP	73
#define P_SLIP	74
#define P_UUCP	75
#define P_CHGPASS	76
#define E_NOUID	77
#define E_UNKNOWNUSER	78
#define T_USERACCT	79
#define I_CANEDIT	80
#define I_SELECT	81
#define P_USERDB	82
#define I_USERCREATE	83
#define Q_USERCREATE	84
#define W_CHGPASS	85
#define Q_ENTEROLDPASS	86
#define Q_ENTERNEWPASS	87
#define Q_RETYPE	88
#define Q_DELGROUP	89
#define T_PASSMNG	90
#define F_PASSMAY	91
#define F_PASSMUST	92
#define F_PASSWARN	93
#define F_PASSEXPIRE	94
#define B_PASSWD	95
#define T_PRIVILEGES	96
#define E_NOUSER	97
#define F_ROOTPASS	98
#define F_YOURPASS	99
#define F_MANAGEPOP	100
#define F_MANAGEPPP	101
#define F_MANAGEUUCP	102
#define I_ENTERONEPASS	103
#define E_NOUSERFROMID	104
#define I_EMPTYLINE	105
#define E_SHELLUNKNOWN	106
#define T_USERSHELL	107
#define T_PPPSHELL	108
#define T_SLIPSHELL	109
#define M_USRSHELLS	110
#define M_PPPSHELLS	111
#define M_SLPSHELLS	112
#define T_MANAGEACCT	113
#define O_DENY	114
#define O_PRIVENABLE	115
#define O_PRIVNOAUTH	116
#define F_PRIVENABLE	117
#define E_ROOTID	118
#define T_NEWUSER	119
#define F_WASCHG	120
#define F_STDDURATION	121
#define F_WASISDIS	122
#define E_IVLDDATE	123
#define E_ROOTPASS	124
#define M_EALIAS	125
#define E_SHELLNOTEXEC	126
#define F_NEWPASSWORD	127
#define F_PASSCONFIRM	128
#define T_IDENTIFY	129
#define I_IDENTIFY	130
#define E_IVLDUPASS	131
#define F_ACCOUNT	132
#define F_CURPASSWORD	133
#define N_NEWPASSOK	134
#define I_SERVER	135
#define E_UPASSROOT	136
#define E_ACCTLOCKED	137
#define E_PASSLOCKED	138
#define E_PASSWAIT	139
#define E_PICKNEW	140
#define F_CRONRANGE	141
#define F_COMMAND	142
#define F_MONTHS	143
#define F_ISJANUARY	144
#define F_ISDECEMBER	145
#define F_DMONTH	146
#define F_DWEEK	147
#define F_ISSUNDAY	148
#define F_ISSATURDAY	149
#define F_HOURS	150
#define F_MINUTES	151
#define T_CRONENTRY	152
#define I_CRONENTRY	153
#define T_JOBS	154
#define B_TASKS	155
#define F_3VALUES	156
#define F_CRONSTEP	157
#define F_ENABLED	158
#define P_CRON	159
#define F_EVERY	160
#define F_MONTH	161
#define F_DAYOFMONTH	162
#define F_DAYOFWEEK	163
#define F_hOURS	164
#define F_mINUTES	165
#define T_BASE	166
#define T_PARAMS	167
#define M_NORMAL	168
#define T_PRIVROOTEQUIV	169
#define T_PSYSCONTROL	170
#define T_CHGROOTPASS	171
#define I_ENTERROOTPASS	172
#define T_POLICIES	173
#define E_PASSWDCMD	174
#define E_UNLOCKPASS	175
#define H_GROUPS	176
#define F_USERPREFIX	177
#define I_USERPREFIX	178
#define T_USERPREFIX	179
#define H_USERS	180
#define T_GDISKQUOTA	181
#define T_UDEFDISKQUOTA	182
#define T_DISKQUOTA	183
#define F_DEFSHELL	184
#define E_IVLDDEF	185
#define E_NOSPACE	186
#define E_IVLDPERIOD	187
#define E_UEXIST	188
#define E_UNOTEXIST	189
#define T_SPCACCTS	190
#define X_PASSWD	191
#define X_TASKS	192
#define F_DEFHOME	193
#define E_GNOTEXIST	194
#define F_NEWUSERCMD	195
#define F_DELETECMD	196
#define E_NOTDEL	197
#define I_NOTDEL	198
#define E_DELANYWAY	199
#define I_DELANYWAY	200
#define E_PREDELFAIL	201
#define F_PRIVGROUP	202
#define I_PRIVGROUP	203
#define E_NOGROUP	204
#define I_CREATEGROUP	205
#define T_CREATGROUP	206
#define F_SUPGROUP	207
#define E_IVLDSUPGROUP	208
#define F_GECOSPREFIX	209
#define F_UID_FROM	210
#define F_UID_TO	211
#define E_GEXIST	212
#define F_GROUPOPT	213
#define F_ARCHIVECMD	214
#define F_POSTDELCMD	215
#define I_ARCHACCTDATA	216
#define I_DELACCTDATA	217
#define I_LEAVEDATA	218
#define T_DELACCT	219
#define I_DELACCT	220
#define I_ENABLED	221
#define T_YOURNAME	222
#define I_YOURNAME	223
#define E_PASSCHG	224
#define I_DELETING	225
#define I_CREATING	226
#define T_SPCLINKS	227
#define T_CHGPASS	228
#define T_EdITUSERS	229
#define T_HOMEDIRS	230
#define F_DIFFDIR	231
#define I_CREATEHOME	232
#define F_HOMEBASE	233
#define F_CREATEPERM	234
#define Q_MISSBASE	235
#define T_MISSBASE	236
#define E_IVLDDIR	237
#define I_USAGE	238
#define F_DONOTHING	239
#define F_CHOWNDIR	240
#define T_FIXHOME	241
#define F_CHOWNRECUR	242
#define I_IGNORED	243
#define T_USERPRIVI	244
#define T_GENPRIVI	245
#define T_USERADMPRIVI	246
#define T_THISHELP	247
#define E_IVLDLOGINCHAR	248
#define E_FAILCREATE	249
#define P_USERACCOUTS	250
#define N_MAXALTGR	251
#define I_SHOWSHADOW	252
#define I_EDITHOME	253
#define T_SCRIPTS	254
#define I_EDITSHELL	255
#define I_EDITQUOTA	256
#define I_EDITTASKS	257
#define E_ISLOGGED	258
#define I_SHOWEXPIRE	259
#define E_UIDRANGE	260
#define T_VISIBILITY	261
#define H_CRONJOBS	262
#define I_JOBS	263
#define E_UNKNOWNGMEMBER	264
#define E_MAXUSERS	265
#define F_EVERY3	266
#define E_DELUSEROPT	267
#define P_ROOTPASS	268
